
Changelog
=========

0.8.0 (2018-12-02)
------------------

o Improved test coverage
o Improved linter issues
o Bugs fixed
o Improved documentation for scorers
o Removed kwargs for scorers and exporters
o Adapted exporters to classes


0.7.0 (2018-12-01)
------------------

o First public version
